@@ -17,12 +17,13 @@ sub EXT_controller : Extend('Ext.app.ViewController') {
             view.add({xtype: 'spacer'});
             view.add({xtype: '$type{'profile'}'});
             view.add({xtype: '$type{'bottom'}'});
+            view.add({xtype: '$type{'version'}'});
 
             var session = this.getViewModel().get('session'),
                 localeButton = this.lookup('change-locale-button'),
-                locales = this.getViewModel().get('settings').locales;
+                locales = this.getViewModel().get('session').locales;
 
-            if (view.getShowLocalesButton() && Ext.isObject(locales) && !Ext.Object.isEmpty(locales)) {
+            if (view.getShowLocalesButton() && !Ext.Object.isEmpty(locales)) {
                 var localeMenu = [];
 
                 for (var locale of Object.keys(locales).sort()) {
@@ -33,7 +34,6 @@ sub EXT_controller : Extend('Ext.app.ViewController') {
                     });
                 }
 
-                localeButton.setText(locales[Ext.L10N.getCurrentLocale()]);
                 localeButton.setMenu(localeMenu);
             }
             else {
@@ -57,19 +57,10 @@ JS
 JS
 
         setLocale => func [ 'menuItem', 'e' ], <<"JS",
-            var locales = this.getViewModel().get('settings').locales,
-                localeButton = this.lookup('change-locale-button');
-
             this.getView().hide();
 
-            localeButton.setText(locales[menuItem.value]);
-
             Ext.fireEvent('setLocale', menuItem.value);
 
-JS
-
-        toggleDarkMode => func [ 'button', 'newVal', 'oldVal', 'eOpts' ], <<'JS',
-            Ext.fireEvent('setTheme', {darkMode: newVal});
 JS
 
         signout => func <<"JS",
@@ -160,20 +151,31 @@ sub EXT_profile : Extend('Ext.Panel') {
 sub EXT_bottom : Extend('Ext.Panel') {
     return {
         layout  => 'hbox',
-        padding => 10,
+        padding => '0 10 0 10',
 
         items => [
-            {   xtype      => 'togglefield',
-                label      => l10n('DARK MODE'),
-                labelAlign => 'right',
-                bind       => '{session.theme.darkMode}',
-                listeners  => { change => 'toggleDarkMode' },
+            {   xtype    => 'togglefield',
+                boxLabel => l10n('DARK MODE'),
+                bind     => '{session.theme.darkMode}',
             },
+            { xtype => 'spacer' },
             {   reference => 'change-locale-button',
                 xtype     => 'button',
                 iconCls   => $FAS_LANGUAGE,
                 textAlign => 'left',
-                width     => 150,
+                bind      => '{session.localeName}',
+            },
+        ],
+    };
+}
+
+sub EXT_version : Extend('Ext.Panel') {
+    return {
+        padding => '10 10 0 10',
+
+        items => [
+            {   xtype => 'component',
+                bind  => 'Version: {session.version.release_id} ({session.version.node})',
             },
         ],
     };
